From a037fd5e1ee0f6e892e55e952219b90747cad08b Mon Sep 17 00:00:00 2001
From: Debo <debottam.bakshi.gupta@cern.ch>
Date: Mon, 5 Oct 2020 13:41:51 +0200
Subject: [PATCH] Switching off DEBUG options and renaming topoHypoTools to
 more inclusive names for electron and photon

---
 ...ypoTool.cxx => TrigEgammaDPhiHypoTool.cxx} | 22 ++++++++++---------
 ...PhiHypoTool.h => TrigEgammaDPhiHypoTool.h} | 21 +++++++++---------
 ...ypoTool.cxx => TrigEgammaMassHypoTool.cxx} | 22 ++++++++++---------
 ...assHypoTool.h => TrigEgammaMassHypoTool.h} | 18 +++++++--------
 .../src/components/TrigEgammaHypo_entries.cxx |  8 +++----
 .../share/ref_RDOtoRDOTrig_v1Dev_build.ref    |  3 +++
 .../share/ref_data_v1Dev_build.ref            |  3 +++
 .../HLTMenuConfig/Egamma/ElectronDef.py       |  9 ++++++--
 .../python/HLTMenuConfig/Egamma/PhotonDef.py  | 13 ++++++-----
 .../Egamma/PhotonSequenceSetup.py             |  5 +----
 .../python/HLTMenuConfig/Menu/LS2_v1.py       |  2 +-
 11 files changed, 69 insertions(+), 57 deletions(-)
 rename Trigger/TrigHypothesis/TrigEgammaHypo/src/{TrigEgammaDiphotonDPhiHypoTool.cxx => TrigEgammaDPhiHypoTool.cxx} (65%)
 rename Trigger/TrigHypothesis/TrigEgammaHypo/src/{TrigEgammaDiphotonDPhiHypoTool.h => TrigEgammaDPhiHypoTool.h} (74%)
 rename Trigger/TrigHypothesis/TrigEgammaHypo/src/{TrigEgammaDielectronMassHypoTool.cxx => TrigEgammaMassHypoTool.cxx} (65%)
 rename Trigger/TrigHypothesis/TrigEgammaHypo/src/{TrigEgammaDielectronMassHypoTool.h => TrigEgammaMassHypoTool.h} (80%)

diff --git a/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDiphotonDPhiHypoTool.cxx b/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDPhiHypoTool.cxx
similarity index 65%
rename from Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDiphotonDPhiHypoTool.cxx
rename to Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDPhiHypoTool.cxx
index 4996af7b514..dbac3449532 100644
--- a/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDiphotonDPhiHypoTool.cxx
+++ b/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDPhiHypoTool.cxx
@@ -4,7 +4,7 @@
 
 /**************************************************************************
  **
- **   File: Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDiphotonDPhiHypoTool.h
+ **   File: Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDPhiHypoTool.h
  **
  **   Description: - Hypothesis Tool: search for photon pairs with
  **                deltaPhi more than a threshold value; intended for H->gg
@@ -14,17 +14,17 @@
  **************************************************************************/
 
 
-#include "TrigEgammaDiphotonDPhiHypoTool.h"
+#include "TrigEgammaDPhiHypoTool.h"
 
 #include <cmath>
 
 using namespace TrigCompositeUtils;
 
-TrigEgammaDiphotonDPhiHypoTool::TrigEgammaDiphotonDPhiHypoTool(const std::string& type, const std::string& name, const IInterface* parent)
+TrigEgammaDPhiHypoTool::TrigEgammaDPhiHypoTool(const std::string& type, const std::string& name, const IInterface* parent)
     : ComboHypoToolBase(type, name, parent) {}
 
 
-StatusCode TrigEgammaDiphotonDPhiHypoTool::initialize()
+StatusCode TrigEgammaDPhiHypoTool::initialize()
 {
   ATH_MSG_DEBUG("AcceptAll            = " << m_acceptAll );
   ATH_MSG_DEBUG("ThresholdDPhiCut         = " << m_thresholdDPhiCut );
@@ -39,8 +39,10 @@ StatusCode TrigEgammaDiphotonDPhiHypoTool::initialize()
   return StatusCode::SUCCESS;
 }
 
-bool TrigEgammaDiphotonDPhiHypoTool::executeAlg(std::vector<LegDecision> &combination) const {
+bool TrigEgammaDPhiHypoTool::executeAlg(std::vector<LegDecision> &combination) const {
 
+  auto dphiOfAccepted = Monitored::Scalar( "DphiOfAccepted"   , -99 );
+  auto monitorIt    = Monitored::Group( m_monTool, dphiOfAccepted);
 //retrieve the electrons 
   std::vector<ElementLink<xAOD::IParticleContainer>> selected_photons;
   for (auto el: combination){
@@ -52,18 +54,18 @@ bool TrigEgammaDiphotonDPhiHypoTool::executeAlg(std::vector<LegDecision> &combin
   auto photonLink2=selected_photons[1];
   TLorentzVector hlv1 = (*photonLink1)->p4();
   TLorentzVector hlv2 = (*photonLink2)->p4();
-  double dPhi = hlv1.DeltaPhi(hlv2);
-  ATH_MSG_DEBUG("Found two Photons with deltaPhi " <<dPhi);
+  dphiOfAccepted = hlv1.DeltaPhi(hlv2);
+  ATH_MSG_DEBUG("Found two Photons with deltaPhi " <<dphiOfAccepted);
 
   // apply the cut
   bool pass=true;
-  if (dPhi<m_thresholdDPhiCut){ 
-      ATH_MSG_DEBUG("Combination failed deltaPhi cut: " << dPhi << " not in " << m_thresholdDPhiCut);
+  if (dphiOfAccepted<m_thresholdDPhiCut){ 
+      ATH_MSG_DEBUG("Combination failed deltaPhi cut: " << dphiOfAccepted << " is below " << m_thresholdDPhiCut);
       pass=false;
   }
 
   if (pass)
-     ATH_MSG_DEBUG( " deltaPhi " << dPhi << " is above the threshold "<<m_thresholdDPhiCut<<" This seleciton passed! ");
+     ATH_MSG_DEBUG( " deltaPhi " << dphiOfAccepted << " is above the threshold "<<m_thresholdDPhiCut<<" This seleciton passed! ");
   
 return pass;
 
diff --git a/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDielectronMassHypoTool.cxx b/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaMassHypoTool.cxx
similarity index 65%
rename from Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDielectronMassHypoTool.cxx
rename to Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaMassHypoTool.cxx
index dbe59bbab75..10bc2d6cba7 100644
--- a/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDielectronMassHypoTool.cxx
+++ b/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaMassHypoTool.cxx
@@ -4,7 +4,7 @@
 
 /**************************************************************************
  **
- **   File: Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDielectronMassHypoTool.h
+ **   File: Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaMassHypoTool.h
  **
  **   Description: - Hypothesis Tool: search for electron pairs with
  **                invariant mass in some interval; intended for Z->ee
@@ -19,17 +19,17 @@
  **************************************************************************/
 
 
-#include "TrigEgammaDielectronMassHypoTool.h"
+#include "TrigEgammaMassHypoTool.h"
 
 #include <cmath>
 
 using namespace TrigCompositeUtils;
 
-TrigEgammaDielectronMassHypoTool::TrigEgammaDielectronMassHypoTool(const std::string& type, const std::string& name, const IInterface* parent)
+TrigEgammaMassHypoTool::TrigEgammaMassHypoTool(const std::string& type, const std::string& name, const IInterface* parent)
     : ComboHypoToolBase(type, name, parent) {}
 
 
-StatusCode TrigEgammaDielectronMassHypoTool::initialize()
+StatusCode TrigEgammaMassHypoTool::initialize()
 {
   ATH_MSG_DEBUG("AcceptAll            = " << m_acceptAll );
   ATH_MSG_DEBUG("LowerMassCut         = " << m_lowerMassElectronClusterCut );
@@ -45,7 +45,9 @@ StatusCode TrigEgammaDielectronMassHypoTool::initialize()
   return StatusCode::SUCCESS;
 }
 
-bool TrigEgammaDielectronMassHypoTool::executeAlg(std::vector<LegDecision> &combination) const {
+bool TrigEgammaMassHypoTool::executeAlg(std::vector<LegDecision> &combination) const {
+  auto massOfAccepted = Monitored::Scalar( "MassOfAccepted"   , -1.0 );
+  auto monitorIt    = Monitored::Group( m_monTool, massOfAccepted);
 
 //retrieve the electrons 
   std::vector<ElementLink<xAOD::IParticleContainer>> selected_electrons;
@@ -58,18 +60,18 @@ bool TrigEgammaDielectronMassHypoTool::executeAlg(std::vector<LegDecision> &comb
   auto electronLink2=selected_electrons[1];
   TLorentzVector hlv1 = (*electronLink1)->p4();
   TLorentzVector hlv2 = (*electronLink2)->p4();
-  double mass = (hlv1+hlv2).M();
-  ATH_MSG_DEBUG("Found two Electrons with mass " <<mass);
+  massOfAccepted = (hlv1+hlv2).M();
+  ATH_MSG_DEBUG("Found two Electrons with mass " <<massOfAccepted);
 
   // apply the cut
   bool pass=true;
-  if (mass<m_lowerMassElectronClusterCut || mass>m_upperMassElectronClusterCut){ 
-      ATH_MSG_DEBUG("Combination failed mass cut: " << mass << " not in [" << m_lowerMassElectronClusterCut << "," <<  m_upperMassElectronClusterCut << "]");
+  if (massOfAccepted < m_lowerMassElectronClusterCut || massOfAccepted > m_upperMassElectronClusterCut){ 
+      ATH_MSG_DEBUG("Combination failed mass cut: " << massOfAccepted << " not in [" << m_lowerMassElectronClusterCut << "," <<  m_upperMassElectronClusterCut << "]");
       pass=false;
   }
 
   if (pass)
-     ATH_MSG_DEBUG( " Invariant mass " << mass << " is  within [" <<m_lowerMassElectronClusterCut<< "," << m_upperMassElectronClusterCut << "] This seleciton passed! ");
+     ATH_MSG_DEBUG( " Invariant mass " << massOfAccepted << " is  within [" <<m_lowerMassElectronClusterCut<< "," << m_upperMassElectronClusterCut << "] This seleciton passed! ");
   
   return pass;
 
diff --git a/Trigger/TrigHypothesis/TrigEgammaHypo/src/components/TrigEgammaHypo_entries.cxx b/Trigger/TrigHypothesis/TrigEgammaHypo/src/components/TrigEgammaHypo_entries.cxx
index 183a9e868b7..07f91d74934 100644
--- a/Trigger/TrigHypothesis/TrigEgammaHypo/src/components/TrigEgammaHypo_entries.cxx
+++ b/Trigger/TrigHypothesis/TrigEgammaHypo/src/components/TrigEgammaHypo_entries.cxx
@@ -26,8 +26,8 @@
 #include "../TrigEgammaPrecisionCaloHypoAlgMT.h"
 #include "../TrigEgammaPrecisionPhotonHypoAlgMT.h"
 #include "../TrigEgammaPrecisionElectronHypoAlgMT.h"
-#include "../TrigEgammaDielectronMassHypoTool.h"
-#include "../TrigEgammaDiphotonDPhiHypoTool.h"
+#include "../TrigEgammaMassHypoTool.h"
+#include "../TrigEgammaDPhiHypoTool.h"
 
 DECLARE_COMPONENT( TrigL2CaloHypo )
 DECLARE_COMPONENT( TrigL2ElectronFex )
@@ -57,5 +57,5 @@ DECLARE_COMPONENT( TrigEgammaFastPhotonHypoTool )
 DECLARE_COMPONENT( TrigEgammaPrecisionCaloHypoAlgMT )
 DECLARE_COMPONENT( TrigEgammaPrecisionPhotonHypoAlgMT )
 DECLARE_COMPONENT( TrigEgammaPrecisionElectronHypoAlgMT )
-DECLARE_COMPONENT( TrigEgammaDielectronMassHypoTool )
-DECLARE_COMPONENT( TrigEgammaDiphotonDPhiHypoTool )
+DECLARE_COMPONENT( TrigEgammaMassHypoTool )
+DECLARE_COMPONENT( TrigEgammaDPhiHypoTool )
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/share/ref_RDOtoRDOTrig_v1Dev_build.ref b/Trigger/TrigValidation/TrigAnalysisTest/share/ref_RDOtoRDOTrig_v1Dev_build.ref
index 009533aecf6..267f6019949 100644
--- a/Trigger/TrigValidation/TrigAnalysisTest/share/ref_RDOtoRDOTrig_v1Dev_build.ref
+++ b/Trigger/TrigValidation/TrigAnalysisTest/share/ref_RDOtoRDOTrig_v1Dev_build.ref
@@ -28,6 +28,9 @@ TrigSignatureMoniMT                                 INFO -- #2613484113 Features
 TrigSignatureMoniMT                                 INFO HLT_2g10_loose_mu20_L1MU20 #3765708828
 TrigSignatureMoniMT                                 INFO -- #3765708828 Events         8          8          1          1          1          0          0          0          0          0          -          -          -          -          -          0
 TrigSignatureMoniMT                                 INFO -- #3765708828 Features                             2          2          6          0          0          0          0          0          -          -          -          -          -
+TrigSignatureMoniMT                                 INFO HLT_2g15_tight_dPhi15_L1DPHI-M70-2EM12I #2606736960
+TrigSignatureMoniMT                                 INFO -- #2606736960 Events         0          0          0          0          0          0          -          -          -          -          -          -          -          -          -          0
+TrigSignatureMoniMT                                 INFO -- #2606736960 Features                             0          0          0          0          -          -          -          -          -          -          -          -          -
 TrigSignatureMoniMT                                 INFO HLT_2g20_tight_L12EM15VH #3837353071
 TrigSignatureMoniMT                                 INFO -- #3837353071 Events         2          2          2          0          0          0          -          -          -          -          -          -          -          -          -          0
 TrigSignatureMoniMT                                 INFO -- #3837353071 Features                             2          0          0          0          -          -          -          -          -          -          -          -          -
diff --git a/Trigger/TrigValidation/TriggerTest/share/ref_data_v1Dev_build.ref b/Trigger/TrigValidation/TriggerTest/share/ref_data_v1Dev_build.ref
index e6bce93957d..680f6ae95b0 100644
--- a/Trigger/TrigValidation/TriggerTest/share/ref_data_v1Dev_build.ref
+++ b/Trigger/TrigValidation/TriggerTest/share/ref_data_v1Dev_build.ref
@@ -28,6 +28,9 @@ TrigSignatureMoniMT                                 INFO -- #2613484113 Features
 TrigSignatureMoniMT                                 INFO HLT_2g10_loose_mu20_L1MU20 #3765708828
 TrigSignatureMoniMT                                 INFO -- #3765708828 Events         20         20         0          0          0          0          0          0          0          0          -          -          -          -          -          0          
 TrigSignatureMoniMT                                 INFO -- #3765708828 Features                             0          0          0          0          0          0          0          0          -          -          -          -          -          
+TrigSignatureMoniMT                                 INFO HLT_2g15_tight_dPhi15_L1DPHI-M70-2EM12I #2606736960
+TrigSignatureMoniMT                                 INFO -- #2606736960 Events         20         20         0          0          0          0          -          -          -          -          -          -          -          -          -          0          
+TrigSignatureMoniMT                                 INFO -- #2606736960 Features                             0          0          0          0          -          -          -          -          -          -          -          -          -          
 TrigSignatureMoniMT                                 INFO HLT_2g20_tight_L12EM15VH #3837353071
 TrigSignatureMoniMT                                 INFO -- #3837353071 Events         20         20         0          0          0          0          -          -          -          -          -          -          -          -          -          0          
 TrigSignatureMoniMT                                 INFO -- #3837353071 Features                             0          0          0          0          -          -          -          -          -          -          -          -          -          
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/ElectronDef.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/ElectronDef.py
index c720effd018..b1e35ad0e27 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/ElectronDef.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/ElectronDef.py
@@ -12,6 +12,7 @@ from TriggerMenuMT.HLTMenuConfig.Egamma.ElectronSequenceSetup import fastElectro
 from TriggerMenuMT.HLTMenuConfig.Egamma.PrecisionCaloSequenceSetup import precisionCaloMenuSequence
 from TriggerMenuMT.HLTMenuConfig.Egamma.PrecisionElectronSequenceSetup import precisionElectronMenuSequence
 
+from AthenaMonitoringKernel.GenericMonitoringTool import GenericMonitoringTool, defineHistogram
 #----------------------------------------------------------------
 # fragments generating configuration will be functions in New JO,
 # so let's make them functions already now
@@ -32,11 +33,15 @@ def precisionElectronSequenceCfg( flags ):
 
 # this must be moved to the HypoTool file:
 def diElectronMassComboHypoToolFromDict(chainDict):
-    from TrigEgammaHypo.TrigEgammaHypoConf import TrigEgammaDielectronMassHypoTool
+    from TrigEgammaHypo.TrigEgammaHypoConf import TrigEgammaMassHypoTool
     name = chainDict['chainName']
-    tool= TrigEgammaDielectronMassHypoTool(name)
+    monTool = GenericMonitoringTool("MonTool_"+name)
+    monTool.Histograms = [defineHistogram('MassOfAccepted', type='TH1F', path='EXPERT', title="Mass in accepted combinations [MeV]", xbins=75, xmin=0, xmax=150000)]
+    tool= TrigEgammaMassHypoTool(name)
     tool.LowerMassElectronClusterCut = 50000
     tool.UpperMassElectronClusterCut = 130000
+    monTool.HistPath = 'EgammaMassHypo/'+tool.getName()
+    tool.MonTool = monTool
     return tool
 
 #----------------------------------------------------------------
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/PhotonDef.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/PhotonDef.py
index 69879d416c0..d5505e52f60 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/PhotonDef.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/PhotonDef.py
@@ -2,8 +2,6 @@
 # Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 
-from AthenaCommon.Constants import DEBUG
-
 from AthenaCommon.Logging import logging
 logging.getLogger().info("Importing %s",__name__)
 log = logging.getLogger("TriggerMenuMT.HLTMenuConfig.Egamma.PhotonDef")
@@ -15,7 +13,7 @@ from TriggerMenuMT.HLTMenuConfig.CommonSequences.CaloSequenceSetup import fastCa
 from TriggerMenuMT.HLTMenuConfig.Egamma.PhotonSequenceSetup import fastPhotonMenuSequence, precisionPhotonMenuSequence
 from TriggerMenuMT.HLTMenuConfig.Egamma.PrecisionCaloSequenceSetup import precisionCaloMenuSequence
 
-
+from AthenaMonitoringKernel.GenericMonitoringTool import GenericMonitoringTool, defineHistogram
 #----------------------------------------------------------------
 # fragments generating configuration will be functions in New JO, 
 # so let's make them functions already now
@@ -33,11 +31,14 @@ def precisionPhotonSequenceCfg( flags ):
     return precisionPhotonMenuSequence('Photon')
 
 def diphotonDPhiHypoToolFromDict(chainDict):
-    from TrigEgammaHypo.TrigEgammaHypoConf import TrigEgammaDiphotonDPhiHypoTool
+    from TrigEgammaHypo.TrigEgammaHypoConf import TrigEgammaDPhiHypoTool
     name = chainDict['chainName']
-    tool= TrigEgammaDiphotonDPhiHypoTool(name)
+    monTool = GenericMonitoringTool("MonTool_"+name)
+    monTool.Histograms = [defineHistogram('DphiOfAccepted', type='TH1F', path='EXPERT', title="PrecisionCalo Hypo entries per Phi;Phi", xbins=128, xmin=-3.2, xmax=3.2)]
+    tool= TrigEgammaDPhiHypoTool(name)
     tool.ThresholdDPhiCut = 1.5
-    tool.OutputLevel = DEBUG
+    monTool.HistPath = 'EgammaDphiHypo/'+tool.getName()
+    tool.MonTool = monTool
     return tool
 
 #----------------------------------------------------------------
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/PhotonSequenceSetup.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/PhotonSequenceSetup.py
index aabeba28db8..906e8cf658b 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/PhotonSequenceSetup.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Egamma/PhotonSequenceSetup.py
@@ -1,6 +1,4 @@
-# Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
-
-from AthenaCommon.Constants import DEBUG
+# Copyright (C) 2002-2020 CERN for the benefit of the ATLAS collaboration
 
 # menu components   
 from TriggerMenuMT.HLTMenuConfig.Menu.MenuComponents import MenuSequence, RecoFragmentsPool
@@ -103,7 +101,6 @@ def precisionPhotonMenuSequence(name):
 
     thePrecisionPhotonHypo = TrigEgammaPrecisionPhotonHypoAlgMT(name+"precisionPhotonHypo")
     thePrecisionPhotonHypo.Photons = sequenceOut
-    thePrecisionPhotonHypo.OutputLevel = DEBUG
 
     return MenuSequence( Sequence    = sequence,
                          Maker       = precisionPhotonViewsMaker, 
diff --git a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/LS2_v1.py b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/LS2_v1.py
index b8e6236f7c3..5cefc600f9a 100644
--- a/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/LS2_v1.py
+++ b/Trigger/TriggerCommon/TriggerMenuMT/python/HLTMenuConfig/Menu/LS2_v1.py
@@ -173,7 +173,7 @@ def setupMenu():
 
         #ATR-21882
         ChainProp(name='HLT_2g15_tight_dPhi15_L1DPHI-M70-2EM12I', l1SeedThresholds=['EM12'], groups=MultiPhotonGroup),
-        ChainProp(name='HLT_2g15_tight_dPhi15_L12EM7', groups=MultiPhotonGroup),
+
         ChainProp(name='HLT_g300_etcut_L1EM22VHI', groups=SinglePhotonGroup),
     ]
 
diff --git a/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDiphotonDPhiHypoTool.h b/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDPhiHypoTool.h
similarity index 74%
rename from Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDiphotonDPhiHypoTool.h
rename to Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDPhiHypoTool.h
index 3a16342ae08..4133d609766 100644
--- a/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDiphotonDPhiHypoTool.h
+++ b/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDPhiHypoTool.h
@@ -2,17 +2,17 @@
   Copyright (C) 2002-2020 CERN for the benefit of the ATLAS collaboration
 */
 
-#ifndef TRIGEGAMMAHYPO_TRIGEGAMMADIPHOTONDPHIHYPOTOOL_H
-#define TRIGEGAMMAHYPO_TRIGEGAMMADIPHOTONDPHIHYPOTOOL_H
+#ifndef TRIGEGAMMAHYPO_TRIGEGAMMADPHIHYPOTOOL_H
+#define TRIGEGAMMAHYPO_TRIGEGAMMADPHIHYPOTOOL_H
 
 /**************************************************************************
  **
- **   File: Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDiphotonDPhiHypoTool.h
+ **   File: Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDPhiHypoTool.h
  **
  **   Description: - Hypothesis Tool: search for photon pairs with 
  **                deltaPhi more than a threshold value; intended for H->gg
  **
- **   Author: D. BakshiGupta  <debottam.bakshigupta@cern.ch>
+ **   Author: Debottam BakshiGupta  <debottam.bakshigupta@cern.ch>
  **
  **************************************************************************/ 
 
@@ -35,23 +35,23 @@
 
 
 /**
  * \class TrigEgammaDiphotonDPhiHypoTool
  * \brief TrigEgammaDiphotonDPhiHypoTool is a ComboHypoTool that calculates the deltaPhi distance 
  * Apply the threshold cut and accepts the event if condition is 
  * satisfied
  *
  */
 
 
-class TrigEgammaDiphotonDPhiHypoTool:  public ComboHypoToolBase {
+class TrigEgammaDPhiHypoTool:  public ComboHypoToolBase {
 
  public:
   
-  TrigEgammaDiphotonDPhiHypoTool(const std::string& type,
+  TrigEgammaDPhiHypoTool(const std::string& type,
                     const std::string& name,
                     const IInterface* parent);
   
-  virtual ~TrigEgammaDiphotonDPhiHypoTool() {};
+  virtual ~TrigEgammaDPhiHypoTool() {};
   virtual StatusCode initialize() override;
 
 
@@ -68,8 +68,7 @@ class TrigEgammaDiphotonDPhiHypoTool:  public ComboHypoToolBase {
   // monitoring
   ToolHandle<GenericMonitoringTool> m_monTool { this, "MonTool", "", "Monitoring tool" };
 
-
-}; // TRIGEGAMMAHYPO_TRIGEGAMMADIPHOTONDPHIHYPOTOOL_H
+}; // TRIGEGAMMAHYPO_TRIGEGAMMADPHIHYPOTOOL_H
 #endif
 
 
@@ -35,23 +35,23 @@
 
 /**
- * \class TrigEgammaDiphotonDPhiHypoTool
- * \brief TrigEgammaDiphotonDPhiHypoTool is a ComboHypoTool that calculates the deltaPhi distance 
+ * \class TrigEgammaDPhiHypoTool
+ * \brief TrigEgammaDPhiHypoTool is a ComboHypoTool that calculates the deltaPhi distance 
  * Apply the threshold cut and accepts the event if condition is 
  * satisfied
diff --git a/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDielectronMassHypoTool.h b/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaMassHypoTool.h
similarity index 80%
rename from Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDielectronMassHypoTool.h
rename to Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaMassHypoTool.h
index 74ef7235896..f64ac521ba7 100644
--- a/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDielectronMassHypoTool.h
+++ b/Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaMassHypoTool.h
@@ -2,12 +2,12 @@
   Copyright (C) 2002-2020 CERN for the benefit of the ATLAS collaboration
 */
 
-#ifndef TRIGEGAMMAHYPO_TRIGEGAMMADIELECTRONMASSHYPOTOOL_H
-#define TRIGEGAMMAHYPO_TRIGEGAMMADIELECTRONMASSHYPOTOOL_H
+#ifndef TRIGEGAMMAHYPO_TRIGEGAMMAMASSHYPOTOOL_H
+#define TRIGEGAMMAHYPO_TRIGEGAMMAMASSHYPOTOOL_H
 
 /**************************************************************************
  **
- **   File: Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaDielectronMassHypoTool.h
+ **   File: Trigger/TrigHypothesis/TrigEgammaHypo/src/TrigEgammaMassHypoTool.h
  **
  **   Description: - Hypothesis Tool: search for electron pairs with 
  **                invariant mass in some interval; intended for Z->ee
@@ -39,23 +39,23 @@
 
 
 /**
  * \class TrigEgammaDielectronMassHypoTool
  * \brief TrigEgammaDielectronMassHypoTool is a ComboHypoTool that calculates the inv mass
  * Apply inv mass cuts (upper and lower cut) to the two electrons and accepts the event if condition is 
  * satisfied
  *
  */
 
 
-class TrigEgammaDielectronMassHypoTool:  public ComboHypoToolBase {
+class TrigEgammaMassHypoTool:  public ComboHypoToolBase {
 
  public:
   
-  TrigEgammaDielectronMassHypoTool(const std::string& type,
+  TrigEgammaMassHypoTool(const std::string& type,
                     const std::string& name,
                     const IInterface* parent);
   
-  virtual ~TrigEgammaDielectronMassHypoTool() {};
+  virtual ~TrigEgammaMassHypoTool() {};
   virtual StatusCode initialize() override;
 
 
@@ -74,7 +74,7 @@ class TrigEgammaDielectronMassHypoTool:  public ComboHypoToolBase {
   ToolHandle<GenericMonitoringTool> m_monTool { this, "MonTool", "", "Monitoring tool" };
 
 
-}; // TRIGEGAMMAHYPO_TRIGEGAMMADIELECTRONMASSHYPOTOOL_H
+}; // TRIGEGAMMAHYPO_TRIGEGAMMAMASSHYPOTOOL_H
 #endif
 
 
@@ -39,23 +39,23 @@
 
 /**
- * \class TrigEgammaDielectronMassHypoTool
- * \brief TrigEgammaDielectronMassHypoTool is a ComboHypoTool that calculates the inv mass
+ * \class TrigEgammaMassHypoTool
+ * \brief TrigEgammaMassHypoTool is a ComboHypoTool that calculates the inv mass
  * Apply inv mass cuts (upper and lower cut) to the two electrons and accepts the event if condition is 
  * satisfied
-- 
GitLab